@@ -4,7 +4,7 @@
 # Pod stripped from pm file by OODoc 2.02.
 package Dancer2::Plugin::LogReport;
 use vars '$VERSION';
-$VERSION = '1.17';
+$VERSION = '1.18';
 
 
 use warnings;
@@ -129,7 +129,7 @@ on_plugin_import
 
 sub process($$)
 {   my ($dsl, $coderef) = @_;
-    try { $coderef->() } hide => 'ALL';
+    try { $coderef->() } hide => 'ALL', on_die => 'PANIC';
     my $success = $@->died ? 0 : 1;
     $@->reportAll(is_fatal => 0);
     $success;
